@@ -3,7 +3,7 @@ package MojoX::JSONRPC2::HTTP;
 use Mojo::Base -base;
 use Carp;
 
-our $VERSION = 'v2.0.0';
+our $VERSION = 'v2.0.1';
 
 use Mojo::UserAgent;
 use JSON::RPC2::Client;
@@ -83,11 +83,11 @@ sub _response {
     }
     # use HTTP code as error message instead of 'Parse error' for:
     # - strange HTTP reply code or non-empty content (notify)
-    elsif ($is_notify  && !($res->is_status_class(HTTP_200) && $res->body =~ /\A\s*\z/ms)) {
+    elsif ($is_notify  && !($res->is_success && $res->body =~ /\A\s*\z/ms)) {
         $failed = sprintf '%d %s', $res->code, $res->message;
     }
     # - strange HTTP reply code or non-json content (call)
-    elsif (!$is_notify && !($res->is_status_class(HTTP_200) && $res->body =~ /\A\s*[{\[]/ms)) {
+    elsif (!$is_notify && !($res->is_success && $res->body =~ /\A\s*[{\[]/ms)) {
         $failed = sprintf '%d %s', $res->code, $res->message;
     }
     elsif (!$is_notify) {
@@ -118,7 +118,7 @@ MojoX::JSONRPC2::HTTP - Client for JSON RPC 2.0 over HTTP
 
 =head1 VERSION
 
-This document describes MojoX::JSONRPC2::HTTP version v2.0.0
+This document describes MojoX::JSONRPC2::HTTP version v2.0.1
 
 
 =head1 SYNOPSIS
@@ -172,53 +172,49 @@ All these methods return current value when called without params or set
 new value and return their object (to allow method chaining) when called
 with single param.
 
-=over
-
-=item url
+=head2 url
 
 RPC endpoint url.
 
 This is only required parameter which must be set before doing RPC calls.
 
-=item method
+=head2 method
 
 Default is C<'POST'>, and only another supported value is C<'GET'>.
 
-=item type
+=head2 type
 
 Default is C<'application/json'>.
 
-=item headers
+=head2 headers
 
 Default is empty HASHREF. Either modify it by reference or set it to your
 own HASHREF with any extra headers you need to send with RPC call.
 
-=item ua
+=head2 ua
 
 C<Mojo::UserAgent> object used for sending HTTP requests - feel free to
 setup it or replace with your own object.
 
-=back
-
 
 =head1 METHODS
 
-=over
+=head2 new
 
-=item new( %attrs )
-
-=item new( \%attrs )
+    $client = MojoX::JSONRPC2::HTTP->new( %attrs );
+    $client = MojoX::JSONRPC2::HTTP->new( \%attrs );
 
 You can set attributes listed above by providing their values when calling
 C<new()> or later using individual attribute methods.
 
-=item call( 'method', @params )
+=head2 call
 
-=item call( 'method', @params, \&cb )
+=head2 call_named
 
-=item call_named( 'method', %params )
-
-=item call_named( 'method', %params, \&cb )
+    ($failed, $result, $error) = $client->call( 'method', @params );
+    ($failed, $result, $error) = $client->call_named( 'method', %params );
+    $client->call( 'method', @params, \&cb );
+    $client->call_named( 'method', %params, \&cb );
 
 Do blocking or non-blocking (when C<\&cb> param provided) RPC calls, with
 either positional or named params. Blocking calls will return these values
@@ -237,13 +233,14 @@ optionally C<{data}>, while C<$failed> and C<$result> will be undefined.
 Otherwise value returned by remote C<'method'> will be in C<$result>,
 while C<$failed> and C<$error> will be undefined.
 
-=item notify( 'method', @params )
+=head2 notify
 
-=item notify( 'method', @params, \&cb )
+=head2 notify_named
 
-=item notify_named( 'method', %params )
-
-=item notify_named( 'method', %params, \&cb )
+    $failed = $client->notify( 'method', @params );
+    $failed = $client->notify_named( 'method', %params );
+    $client->notify( 'method', @params, \&cb );
+    $client->notify_named( 'method', %params, \&cb );
 
 Do blocking or non-blocking (when C<\&cb> param provided) RPC calls, with
 either positional or named params. Blocking calls will return this value
@@ -254,8 +251,6 @@ either positional or named params. Blocking calls will return this value
 It will contain error message in case of transport-level error or will be
 undefined if RPC call was executes successfully.
 
-=back
-
 
 =head1 SEE ALSO
 
@@ -325,7 +320,7 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2014- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
